<?php

namespace Drupal\drd\Entity;

/**
 * Provides an interface for defining Core entities.
 *
 * @ingroup drd
 */
interface CoreInterface extends BaseInterface {

  /**
   * Get language code of the core.
   *
   * @return string
   *   Language code.
   */
  public function getLangCode();

  /**
   * Get Drupal root directory of the core.
   *
   * @return string
   *   The Drupal root directory.
   */
  public function getDrupalRoot();

  /**
   * Gets the Core host.
   *
   * @return \Drupal\drd\Entity\HostInterface
   *   Host of the Core.
   */
  public function getHost();

  /**
   * Sets the Core drupal release.
   *
   * @param ReleaseInterface $release
   *   The Core drupal release.
   *
   * @return $this
   */
  public function setDrupalRelease(ReleaseInterface $release);

  /**
   * Gets the Core drupal release.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface
   *   Drupal release of the Core.
   */
  public function getDrupalRelease();

  /**
   * Get the update settings for the core.
   *
   * @return array
   *   The update settings.
   */
  public function getUpdateSettings();

  /**
   * Get the update plugin for the core.
   *
   * @return \Drupal\drd\Update\PluginStorageInterface
   *   The update plugin.
   */
  public function getUpdatePlugin();

  /**
   * Sets the Core host.
   *
   * @param HostInterface $host
   *   The Core host.
   *
   * @return $this
   */
  public function setHost(HostInterface $host);

  /**
   * Get all domains of the core.
   *
   * @param array $properties
   *   Properties for the query.
   *
   * @return \Drupal\drd\Entity\DomainInterface[]
   *   List of domains of this core.
   */
  public function getDomains(array $properties = []);

  /**
   * Get the first active domain for this core.
   *
   * @return \Drupal\drd\Entity\DomainInterface
   *   A domain entity.
   */
  public function getFirstActiveDomain();

  /**
   * Get all releases for which updates are available.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface[]
   *   List of release entities.
   */
  public function getAvailableUpdates();

  /**
   * Get list of update logs.
   *
   * @return array
   *   List of update logs.
   */
  public function getUpdateLogList();

  /**
   * Get update log from a specific timestamp.
   *
   * @param int $timestamp
   *   Timestamp to select which update log to return.
   *
   * @return string
   *   The update log.
   */
  public function getUpdateLog($timestamp);

  /**
   * Dave a collected  update log.
   *
   * @param string $log
   *   The update log.
   *
   * @return $this
   */
  public function saveUpdateLog($log);

}
