<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Url;

/**
 * Provides a 'WidgetQueue' block.
 *
 * @Block(
 *  id = "drd_queue",
 *  admin_label = @Translation("DRD Queue"),
 *  weight = -3,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetQueue extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  protected function title() {
    return $this->t('Action Queue');
  }

  /**
   * {@inheritdoc}
   */
  protected function content() {
    $c = \Drupal::service('queue.drd')->countItems();
    if (empty($c)) {
      $args = [];
      $message = '<p>Your queue is empty.</p>';
    }
    else {
      $args = [
        '%count' => $c,
        '@cron' => (new Url('system.cron', ['key' => \Drupal::state()->get('system.cron_key')]))->toString(),
      ];
      $message = '<p class="message">You have %count action in your queue.</p>';
      $message .= '<p>Actions from the queue will be executed:</p><ul>';
      $message .= '<li>next time cron is being executed</li>';
      $message .= '<li>by <a href="@cron">running cron</a> now</li>';
      if (\Drupal::moduleHandler()->moduleExists('queue_ui')) {
        $args['@queueui'] = (new Url('queue_ui.overview_form'))->toString();
        $message .= '<li>by <a href="@queueui">batch processing</a> the queue</li>';
      }
      else {
        $message .= '<li>(The module <a href="https://www.drupal.org/project/queue_ui">Queue UI</a> is not installed but recommended.)</li>';
      }
      $message .= '</ul>';
    }

    return new FormattableMarkup($message, $args);
  }

}
