<?php

namespace Drupal\drd;

use Drupal\Core\Queue\SuspendQueueException;
use Drupal\drd\Entity\BaseInterface;
use Drupal\drd\Plugin\Action\Base as ActionBase;

/**
 * Easy access to the DRD queue.
 */
class QueueManager {

  /**
   * Get the DRD Queue.
   *
   * @return \Drupal\Core\Queue\QueueInterface
   *   The DRD Queue.
   */
  private function getQueue() {
    /* @var \Drupal\Core\Queue\QueueFactory $queue_factory */
    $queue_factory = \Drupal::service('queue');
    return $queue_factory->get('drd');
  }

  public function processAll() {
    /* @var $queueWorkerManager \Drupal\Core\Queue\QueueWorkerManagerInterface */
    $queueWorkerManager = \Drupal::service('plugin.manager.queue_worker');
    /* @var \Drupal\Core\Queue\QueueWorkerInterface $queueWorker */
    $queueWorker = $queueWorkerManager->createInstance('drd');
    $queue = $this->getQueue();

    while ($item = $queue->claimItem()) {
      try {
        $queueWorker->processItem($item->data);
        $queue->deleteItem($item);
      }
      catch (SuspendQueueException $ex1) {
        $queue->releaseItem($item);
        watchdog_exception('DRD Queue', $ex1);
        return;
      }
      catch (\Exception $ex2) {
        watchdog_exception('DRD Queue', $ex2);
      }
    }
  }

  /**
   * Get the number of items in the queue.
   *
   * @return int
   *   The number of items.
   */
  public function countItems() {
    return $this->getQueue()->numberOfItems();
  }

  /**
   * Add a new item to the queue.
   *
   * @param \Drupal\drd\Plugin\Action\Base $action
   *   The action.
   * @param \Drupal\drd\Entity\BaseInterface $entity
   *   The entity.
   */
  public function createItem(ActionBase $action, BaseInterface $entity = NULL) {
    $item = new \stdClass();
    $item->action = $action;
    $item->entity = $entity;
    $item->arguments = $action->getArguments();
    $this->getQueue()->createItem($item);
  }

  /**
   * Add new items to the queue.
   *
   * @param \Drupal\drd\Plugin\Action\Base $action
   *   The action.
   * @param \Drupal\drd\Entity\BaseInterface[] $entities
   *   The entities.
   */
  public function createItems(ActionBase $action, array $entities) {
    foreach ($entities as $entity) {
      $this->createItem($action, $entity);
    }
  }

}
